PyAlloc

Struct PyAlloc 

pub struct PyAlloc {
    pub inner: Option<Box<dyn Alloc + Sync + Send>>,
    pub bootstrap_command: Option<BootstrapCommand>,
}
A python class that wraps a Rust Alloc trait object. It represents what is shown on the python side. Internals are not exposed. It ensures that the Alloc is only used once (i.e. moved) in rust.

Fields

inner: Option<Box<dyn Alloc + Sync + Send>>bootstrap_command: Option<BootstrapCommand>

Implementations

Source

impl PyAlloc

pub fn new( inner: Box<dyn Alloc + Sync + Send>, bootstrap_command: Option<BootstrapCommand>, ) -> Self

Create a new PyAlloc with provided boxed trait.

pub fn take(&mut self) -> Option<Box<dyn Alloc + Sync + Send>>

Take the internal Alloc object.

Source

impl PyAlloc

pub fn reshape( &mut self, shape: &Bound<'_, PyDict>, ) -> PyResult<Option<PyAlloc>>