pub struct PyRemoteAllocator { /* private fields */ }Trait Implementations
Sourceimpl Allocator for PyRemoteAllocator
impl Allocator for PyRemoteAllocator
Sourcetype Alloc = RemoteProcessAlloc
type Alloc = RemoteProcessAlloc
The type of
Alloc produced by this allocator.Sourcefn allocate<'life0, 'async_trait>(
&'life0 mut self,
spec: AllocSpec,
) -> Pin<Box<dyn Future<Output = Result<Self::Alloc, AllocatorError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn allocate<'life0, 'async_trait>(
&'life0 mut self,
spec: AllocSpec,
) -> Pin<Box<dyn Future<Output = Result<Self::Alloc, AllocatorError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Create a new allocation. The allocation itself is generally
returned immediately (after validating parameters, etc.);
the caller is expected to respond to allocation events as
the underlying procs are incrementally allocated.
Sourceimpl Clone for PyRemoteAllocator
impl Clone for PyRemoteAllocator
Sourceimpl<'py> IntoPyObject<'py> for PyRemoteAllocator
impl<'py> IntoPyObject<'py> for PyRemoteAllocator
Sourcetype Target = PyRemoteAllocator
type Target = PyRemoteAllocator
The Python output type
Sourcetype Output = Bound<'py, <PyRemoteAllocator as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyRemoteAllocator as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyRemoteAllocator
impl PyClass for PyRemoteAllocator
Sourceimpl PyClassBaseType for PyRemoteAllocator
impl PyClassBaseType for PyRemoteAllocator
type LayoutAsBase = PyClassObject<PyRemoteAllocator>
type BaseNativeType = <PyRemoteAllocator as PyClassImpl>::BaseNativeType
type Initializer = PyClassInitializer<PyRemoteAllocator>
type PyClassMutability = <PyRemoteAllocator as PyClassImpl>::PyClassMutability
Sourceimpl PyClassImpl for PyRemoteAllocator
impl PyClassImpl for PyRemoteAllocator
Sourceconst IS_BASETYPE: bool = true
const IS_BASETYPE: bool = true
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyRemoteAllocator>
type ThreadChecker = SendablePyClass<PyRemoteAllocator>
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForPyRemoteAllocator
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyRemoteAllocator
impl PyClassNewTextSignature for PyRemoteAllocator
const TEXT_SIGNATURE: &'static str = "(alloc_name, initializer)"
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder PyRemoteAllocator
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder PyRemoteAllocator
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder mut PyRemoteAllocator
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder mut PyRemoteAllocator
Sourceimpl PyTypeInfo for PyRemoteAllocator
impl PyTypeInfo for PyRemoteAllocator
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for PyRemoteAllocator