pub struct PyAlloc {
pub inner: Option<Box<dyn Alloc + Sync + Send>>,
pub bootstrap_command: Option<BootstrapCommand>,
}Expand description
A python class that wraps a Rust Alloc trait object. It represents what is shown on the python side. Internals are not exposed. It ensures that the Alloc is only used once (i.e. moved) in rust.
Fields
inner: Option<Box<dyn Alloc + Sync + Send>>bootstrap_command: Option<BootstrapCommand>Implementations